@@ -23,15 +23,15 @@
 
 
 
-#include <kparts/genericfactory.h>
-#include <kaction.h>
-#include <kmessagebox.h>
+#include <tdeparts/genericfactory.h>
+#include <tdeaction.h>
+#include <tdemessagebox.h>
 #include <kstandarddirs.h>
 #include <kxmlguifactory.h>
-#include <ktoolbar.h>
-#include <kio/netaccess.h>
+#include <tdetoolbar.h>
+#include <tdeio/netaccess.h>
 #include <kmimetype.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 
 #include <tqtimer.h>
 #include <tqslider.h>
@@ -146,11 +146,11 @@ bool GStreamerPart::closeURL()
 
 
 
-KAboutData *GStreamerPart::createAboutData()
+TDEAboutData *GStreamerPart::createAboutData()
 {
-	KAboutData* aboutData = new KAboutData( "gstreamerpart", I18N_NOOP("GStreamerPart"),
+	TDEAboutData* aboutData = new TDEAboutData( "gstreamerpart", I18N_NOOP("GStreamerPart"),
 	                                        "0.1", "GStreamer based player part for Kaffeine.",
-	                                        KAboutData::License_GPL,
+	                                        TDEAboutData::License_GPL,
 	                                        "(c) 2005, Jürgen Kofler.", 0, "http://kaffeine.sourceforge.net");
 	aboutData->addAuthor("Jürgen Kofler.",0, "kaffeine@gmx.net");
 
@@ -165,7 +165,7 @@ bool GStreamerPart::openURL(const MRL& mrl)
 
 	// FIXME: thats not the right place for that
 	if ( !m_posToolbar ) {
-		m_posToolbar = (KToolBar*)factory()->container( "gstPositionToolBar", this );
+		m_posToolbar = (TDEToolBar*)factory()->container( "gstPositionToolBar", this );
 		if ( m_posToolbar ) {
 			m_posToolbar->setItemAutoSized( m_posToolbar->idAt(0), true ); //set position slider to maximum width
 		}
@@ -193,7 +193,7 @@ bool GStreamerPart::openURL(const MRL& mrl)
 	{
 		kdDebug() << "GStreamerPart: Check for kaffeine/noatun/m3u/pls/asx playlist\n";
 		TQString localFile;
-		if ( KIO::NetAccess::download(m_mrl.kurl(), localFile, widget()) ) {
+		if ( TDEIO::NetAccess::download(m_mrl.kurl(), localFile, widget()) ) {
 			TQFile file( localFile );
 			file.open( IO_ReadOnly );
 			TQTextStream stream( &file );
@@ -223,7 +223,7 @@ bool GStreamerPart::openURL(const MRL& mrl)
 			}
 		}
 		else
-			kdError() << "GStreamerPart: " << KIO::NetAccess::lastErrorString() << endl;
+			kdError() << "GStreamerPart: " << TDEIO::NetAccess::lastErrorString() << endl;
 	}
 	/* check for ram playlist */
 	if ( (ext == "ra") || (ext == "rm") || (ext == "ram") || (ext == "lsc") || (ext == "pl") ) {
@@ -641,7 +641,7 @@ void GStreamerPart::slotSetVisualPlugin( const TQString& name )
 void GStreamerPart::slotContextMenu( const TQPoint& pos )
 {
 	if (factory()) {
-		KPopupMenu *pop = (KPopupMenu*)factory()->container("context_menu", this);
+		TDEPopupMenu *pop = (TDEPopupMenu*)factory()->container("context_menu", this);
 		if ( pop )
 			pop->popup(pos);
 	}
@@ -652,7 +652,7 @@ void GStreamerPart::slotContextMenu( const TQPoint& pos )
 void GStreamerPart::loadConfig()
 {
 	kdDebug() << "GStreamerPart: Load config" << endl;
-	KConfig* config = instance()->config();
+	TDEConfig* config = instance()->config();
 	config->setGroup("General Options");
 
 	m_audioSinkName = config->readEntry("Audio Sink", "alsasink");
@@ -668,7 +668,7 @@ void GStreamerPart::saveConfig()
 {
 	kdDebug() << "GStreamerPart: Save config" << endl;
 
-	KConfig* config = instance()->config();
+	TDEConfig* config = instance()->config();
 	config->setGroup("General Options");
 
 	config->writeEntry( "Audio Sink", m_audioSinkName );
@@ -692,31 +692,31 @@ void GStreamerPart::slotPrepareForFullscreen( bool fullscreen )
 
 void GStreamerPart::initActions()
 {
-	new KAction(i18n("Toggle Minimal Mode"), 0, 0, this, TQT_SIGNAL(signalToggleMinimalMode()), actionCollection(), "player_minimal_mode");
-	new KAction(i18n("Play"), "player_play", 0, TQT_TQOBJECT(this), TQT_SLOT(slotPlay()), actionCollection(), "player_play");
-	new KAction(i18n("Pause"), "player_pause", Key_Space, TQT_TQOBJECT(this), TQT_SLOT(slotTogglePause()), actionCollection(), "player_pause");
-	new KAction(i18n("Stop"), "player_stop", Key_Backspace, TQT_TQOBJECT(this), TQT_SLOT(slotStop()), actionCollection(), "player_stop");
-	new KAction(i18n("&Next"), "player_end", Key_PageDown, TQT_TQOBJECT(this), TQT_SLOT(slotNext()), actionCollection(), "player_next");
-	new KAction(i18n("&Previous"), "player_start", Key_PageUp, TQT_TQOBJECT(this), TQT_SLOT(slotPrevious()), actionCollection(), "player_previous");
+	new TDEAction(i18n("Toggle Minimal Mode"), 0, 0, this, TQT_SIGNAL(signalToggleMinimalMode()), actionCollection(), "player_minimal_mode");
+	new TDEAction(i18n("Play"), "media-playback-start", 0, TQT_TQOBJECT(this), TQT_SLOT(slotPlay()), actionCollection(), "player_play");
+	new TDEAction(i18n("Pause"), "media-playback-pause", Key_Space, TQT_TQOBJECT(this), TQT_SLOT(slotTogglePause()), actionCollection(), "player_pause");
+	new TDEAction(i18n("Stop"), "media-playback-stop", Key_Backspace, TQT_TQOBJECT(this), TQT_SLOT(slotStop()), actionCollection(), "player_stop");
+	new TDEAction(i18n("&Next"), "media-skip-forward", Key_PageDown, TQT_TQOBJECT(this), TQT_SLOT(slotNext()), actionCollection(), "player_next");
+	new TDEAction(i18n("&Previous"), "media-skip-backward", Key_PageUp, TQT_TQOBJECT(this), TQT_SLOT(slotPrevious()), actionCollection(), "player_previous");
 
 	m_timer = new Timer();
 	new KWidgetAction(m_timer->getSlider(), i18n("Position"), 0, 0, 0, actionCollection(), "player_position");
 	new KWidgetAction((TQWidget*)m_timer->getLabel(), i18n("Playtime"), 0, 0, 0, actionCollection(), "player_playtime");
 
-	m_audioVisual = new KSelectAction(i18n("Audio &Visualization"), 0, actionCollection(), "audio_visual");
+	m_audioVisual = new TDESelectAction(i18n("Audio &Visualization"), 0, actionCollection(), "audio_visual");
 	connect(m_audioVisual, TQT_SIGNAL(activated(const TQString&)), TQT_TQOBJECT(this), TQT_SLOT(slotSetVisualPlugin(const TQString&)));
 	m_audioVisualPluginList.prepend("none");
 	m_audioVisual->setItems(m_audioVisualPluginList);
 	m_audioVisual->setCurrentItem(m_audioVisual->items().findIndex(m_visualPluginName));
 
-	new KAction(i18n("&Mute"), "player_mute", Key_U, TQT_TQOBJECT(this), TQT_SLOT(slotMute()), actionCollection(), "audio_mute");
-	new KAction(i18n("&Auto"), "viewmagfit", Key_F5, TQT_TQOBJECT(m_video), TQT_SLOT(slotAspectRatioAuto()), actionCollection(), "aspect_auto");
-	new KAction(i18n("&4:3"), "viewmagfit", Key_F6, TQT_TQOBJECT(m_video), TQT_SLOT(slotAspectRatio4_3()), actionCollection(), "aspect_43");
-	new KAction(i18n("A&namorphic"), "viewmagfit", Key_F7, TQT_TQOBJECT(m_video), TQT_SLOT(slotAspectRatioAnamorphic()), actionCollection(), "aspect_anamorphic");
-	new KAction(i18n("&DVB"), "viewmagfit", Key_F8, TQT_TQOBJECT(m_video), TQT_SLOT(slotAspectRatioDVB()), actionCollection(), "aspect_dvb");
-	new KAction(i18n("&Square"), "viewmagfit", Key_F9, TQT_TQOBJECT(m_video), TQT_SLOT(slotAspectRatioSquare()), actionCollection(), "aspect_square");
-	new KAction(i18n("&Video Settings"), "configure", Key_V, TQT_TQOBJECT(this), TQT_SLOT(slotVideoSettings()), actionCollection(), "video_settings");
-	new KAction(i18n("Track &Info"), "info", 0 , TQT_TQOBJECT(this), TQT_SLOT(slotInfo()), actionCollection(), "player_track_info");
+	new TDEAction(i18n("&Mute"), "player_mute", Key_U, TQT_TQOBJECT(this), TQT_SLOT(slotMute()), actionCollection(), "audio_mute");
+	new TDEAction(i18n("&Auto"), "zoom-fit-best", Key_F5, TQT_TQOBJECT(m_video), TQT_SLOT(slotAspectRatioAuto()), actionCollection(), "aspect_auto");
+	new TDEAction(i18n("&4:3"), "zoom-fit-best", Key_F6, TQT_TQOBJECT(m_video), TQT_SLOT(slotAspectRatio4_3()), actionCollection(), "aspect_43");
+	new TDEAction(i18n("A&namorphic"), "zoom-fit-best", Key_F7, TQT_TQOBJECT(m_video), TQT_SLOT(slotAspectRatioAnamorphic()), actionCollection(), "aspect_anamorphic");
+	new TDEAction(i18n("&DVB"), "zoom-fit-best", Key_F8, TQT_TQOBJECT(m_video), TQT_SLOT(slotAspectRatioDVB()), actionCollection(), "aspect_dvb");
+	new TDEAction(i18n("&Square"), "zoom-fit-best", Key_F9, TQT_TQOBJECT(m_video), TQT_SLOT(slotAspectRatioSquare()), actionCollection(), "aspect_square");
+	new TDEAction(i18n("&Video Settings"), "configure", Key_V, TQT_TQOBJECT(this), TQT_SLOT(slotVideoSettings()), actionCollection(), "video_settings");
+	new TDEAction(i18n("Track &Info"), "application-vnd.tde.info", 0 , TQT_TQOBJECT(this), TQT_SLOT(slotInfo()), actionCollection(), "player_track_info");
 
 	m_volume = new TQSlider(Qt::Horizontal, 0);
 	TQToolTip::add(m_volume, i18n("Volume"));
@@ -726,7 +726,7 @@ void GStreamerPart::initActions()
 	connect(m_volume, TQT_SIGNAL(valueChanged(int)), TQT_TQOBJECT(this), TQT_SLOT(slotVolume(int)));
 	slotSetVolume(m_savedVolume);
 	new KWidgetAction(m_volume, i18n("Volume"), 0, 0, 0, actionCollection(), "audio_volume");
-	new KAction(i18n("&GStreamer Engine Parameters"), "edit", 0, TQT_TQOBJECT(this), TQT_SLOT(slotConfigDialog()), actionCollection(), "settings_gst_parameter");
+	new TDEAction(i18n("&GStreamer Engine Parameters"), "edit", 0, TQT_TQOBJECT(this), TQT_SLOT(slotConfigDialog()), actionCollection(), "settings_gst_parameter");
 
 	connect(m_video, TQT_SIGNAL(signalRightClick(const TQPoint&)), TQT_TQOBJECT(this), TQT_SLOT(slotContextMenu(const TQPoint&)));
 }
@@ -764,10 +764,20 @@ bool GStreamerPart::initGStreamer()
 	kdDebug() << "GStreamerPart: Found GStreamer version "<<maj<<"."<<min<<"."<<mic<<"."<< nan <<endl<<endl;
 
 	/* check for visualization plugins */
-	GList* factories = gst_registry_get_feature_list(gst_registry_get_default (), GST_TYPE_ELEMENT_FACTORY);
+	GList* factories = gst_registry_get_feature_list(
+#if GST_CHECK_VERSION(1,0,0)
+		gst_registry_get (),
+#else
+		gst_registry_get_default (),
+#endif
+		GST_TYPE_ELEMENT_FACTORY);
 	TQString name, cat;
 	while ( factories ) {
+#if GST_CHECK_VERSION(1,0,0)
+		name =  GST_OBJECT_NAME(factories->data);
+#else
 		name =  GST_PLUGIN_FEATURE_NAME(factories->data);
+#endif
 		cat = gst_element_factory_get_klass(GST_ELEMENT_FACTORY(factories->data));
 		// kdDebug() << "GStreamerPart: Found plugin: " << name << " - Category: " << cat << endl;
 		if ( cat == "Visualization" )
