@@ -20,24 +20,24 @@
 
 #include "xine_part.h"
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kinstance.h>
 #include <kiconloader.h>
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kstdaction.h>
-#include <kfiledialog.h>
-#include <kmessagebox.h>
+#include <tdefiledialog.h>
+#include <tdemessagebox.h>
 #include <kinputdialog.h>
 #include <kxmlguifactory.h>
-#include <kpopupmenu.h>
-#include <kparts/genericfactory.h>
+#include <tdepopupmenu.h>
+#include <tdeparts/genericfactory.h>
 #include <kprogress.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
 #include <kstandarddirs.h>
 #include <dcopclient.h>
 #include <kprocess.h>
 #include <kprotocolinfo.h>
-#include <ktoolbar.h>
+#include <tdetoolbar.h>
 
 #include <tqvbox.h>
 #include <tqlabel.h>
@@ -145,11 +145,11 @@ XinePart::~XinePart()
 		delete m_embeddedContext;
 }
 
-KAboutData *XinePart::createAboutData()
+TDEAboutData *XinePart::createAboutData()
 {
-	KAboutData* aboutData = new KAboutData( "kaffeine", I18N_NOOP("XinePart"),
+	TDEAboutData* aboutData = new TDEAboutData( "kaffeine", I18N_NOOP("XinePart"),
 	                                        KAFFEINE_VERSION, I18N_NOOP("A xine based player part for Kaffeine."),
-	                                        KAboutData::License_GPL,
+	                                        TDEAboutData::License_GPL,
 	                                        "(c) 2003-2004, Jürgen Kofler.", 0, "http://kaffeine.sourceforge.net");
 	aboutData->addAuthor("Jürgen Kofler.",0, "kaffeine@gmx.net");
 
@@ -185,7 +185,7 @@ bool XinePart::openURL(const MRL& mrl)
 	{
 		kdDebug() << "XinePart: Check for kaffeine/noatun/m3u/pls/asx playlist\n";
 		TQString localFile;
-		if (KIO::NetAccess::download(m_mrl.kurl(), localFile, widget()))
+		if (TDEIO::NetAccess::download(m_mrl.kurl(), localFile, widget()))
 		{
 			TQFile file(localFile);
 			file.open(IO_ReadOnly);
@@ -235,7 +235,7 @@ bool XinePart::openURL(const MRL& mrl)
 			}
 		}
 		else
-			kdError() << "XinePart: " << KIO::NetAccess::lastErrorString() << endl;
+			kdError() << "XinePart: " << TDEIO::NetAccess::lastErrorString() << endl;
 	}
 	/* check for ram playlist */
 	if ( (ext == "ra") || (ext == "rm") || (ext == "ram") || (ext == "lsc") || (ext == "pl") )
@@ -243,7 +243,7 @@ bool XinePart::openURL(const MRL& mrl)
 		kdDebug() << "XinePart: Try loading ram playlist\n";
 		playlist = PlaylistImport::ram(m_mrl, m_playlist, widget());
 	}
-	/* urls from audiocd kio-slave */
+	/* urls from audiocd tdeio-slave */
 	if (m_mrl.kurl().protocol() == "audiocd")
 	{
 		TQString audioTrack = TQString::number(m_mrl.kurl().fileName().remove( TQRegExp("\\D" ) ).left(2).toUInt());
@@ -297,7 +297,7 @@ void XinePart::slotPlay(bool forcePlay)
 	MRL mrl = m_playlist[m_current];
 
 	/*
-	 *  is protocol supported by xine or not known by KIO?
+	 *  is protocol supported by xine or not known by TDEIO?
 	 */
 	if ((TQString(SUPPORTED_PROTOCOLS).contains(mrl.kurl().protocol()))
 	        ||  (!KProtocolInfo::isKnownProtocol(mrl.kurl())))
@@ -321,7 +321,7 @@ void XinePart::slotPlay(bool forcePlay)
 		kdDebug() << "XinePart: Protocol not supported by xine, try to download it..." << endl;
 
 		TQString localFile;
-		if (KIO::NetAccess::download(mrl.kurl(), localFile, widget()))
+		if (TDEIO::NetAccess::download(mrl.kurl(), localFile, widget()))
 		{
 			m_xine->clearQueue();
 			m_xine->appendToQueue(localFile);
@@ -334,7 +334,7 @@ void XinePart::slotPlay(bool forcePlay)
 				TQTimer::singleShot(0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotPlay()));
 		}
 		else
-			kdError() << "XinePart: " << KIO::NetAccess::lastErrorString() << endl;
+			kdError() << "XinePart: " << TDEIO::NetAccess::lastErrorString() << endl;
 	}
 }
 
@@ -1155,7 +1155,7 @@ void XinePart::slotContextMenu(const TQPoint& pos)
 {
 	if (factory())
 	{
-		KPopupMenu *pop = (KPopupMenu*)factory()->container("context_menu", this);
+		TDEPopupMenu *pop = (TDEPopupMenu*)factory()->container("context_menu", this);
 		if (pop)
 			pop->popup(pos);
 	}
@@ -1249,7 +1249,7 @@ void XinePart::slotFinalize()
 {
 	if (factory())
 	{
-		KToolBar *pos = (KToolBar*)factory()->container("positionToolBar", this);
+		TDEToolBar *pos = (TDEToolBar*)factory()->container("positionToolBar", this);
 		if (pos)
 		{
 			// pos->alignItemRight(pos->idAt(1), true); //align time widget right
@@ -1261,9 +1261,9 @@ void XinePart::slotFinalize()
 	else
 	{
 		kdDebug() << "XinePart: no xmlguifactory, will create a simple context menu..." << endl;
-		KAction* action = NULL;
-		m_embeddedContext = new KPopupMenu(0);
-		m_embeddedContext->insertTitle(instance()->iconLoader()->loadIcon("kaffeine", KIcon::Small), i18n("Kaffeine Player"));
+		TDEAction* action = NULL;
+		m_embeddedContext = new TDEPopupMenu(0);
+		m_embeddedContext->insertTitle(instance()->iconLoader()->loadIcon("kaffeine", TDEIcon::Small), i18n("Kaffeine Player"));
 		actionCollection()->action("player_play")->plug(m_embeddedContext);
 		actionCollection()->action("player_pause")->plug(m_embeddedContext);
 		actionCollection()->action("player_stop")->plug(m_embeddedContext);
@@ -1276,9 +1276,9 @@ void XinePart::slotFinalize()
 		actionCollection()->action("file_save_screenshot")->plug(m_embeddedContext);
 		actionCollection()->action("file_save_stream")->plug(m_embeddedContext);
 		m_embeddedContext->insertSeparator();
-		action = new KAction(i18n("Copy URL to Clipboard"), "editcopy", 0, TQT_TQOBJECT(this), TQT_SLOT(slotCopyToClipboard()), actionCollection(), "copy_to_clipboard");
+		action = new TDEAction(i18n("Copy URL to Clipboard"), "edit-copy", 0, TQT_TQOBJECT(this), TQT_SLOT(slotCopyToClipboard()), actionCollection(), "copy_to_clipboard");
 		action->plug(m_embeddedContext);
-		action = new KAction(i18n("Play in Kaffeine Externally"), "gear", 0, TQT_TQOBJECT(this), TQT_SLOT(slotLaunchExternally()), actionCollection(), "play_externally");
+		action = new TDEAction(i18n("Play in Kaffeine Externally"), "gear", 0, TQT_TQOBJECT(this), TQT_SLOT(slotLaunchExternally()), actionCollection(), "play_externally");
 		action->plug(m_embeddedContext);
 	}
 
@@ -1293,7 +1293,7 @@ void XinePart::slotFinalize()
 void XinePart::slotCopyToClipboard()
 {
 	kdDebug() << "XinePart: Send URL to klipper: " << m_mrl.url() << endl;
-	DCOPClient* client = KApplication::dcopClient();
+	DCOPClient* client = TDEApplication::dcopClient();
 	if (!client->send("klipper", "klipper", "setClipboardContents(TQString)", m_mrl.url()))
 		kdError() << "Can't send current URL to klipper" << endl;
 }
@@ -1308,109 +1308,109 @@ void XinePart::slotLaunchExternally()
 void XinePart::slotLaunchDelayed()
 {
 	kdDebug() << "XinePart: Start Kaffeine with argument: " << m_mrl.url() << endl;
-	KProcess process;
+	TDEProcess process;
 	process << "kaffeine" << m_mrl.url();
 	kdDebug() << "XinePart: Launching Kaffeine externaly..." << endl;
-	process.start(KProcess::DontCare);
+	process.start(TDEProcess::DontCare);
 	process.detach();
 }
 
 void XinePart::initActions()
 {
-	KAction* action = NULL;
+	TDEAction* action = NULL;
 	/* file menu */
-	m_broadcastSend = new KToggleAction(i18n("&Send Broadcast Stream..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(slotToggleBroadcastSend()), actionCollection(), "network_send");
-	new KAction(i18n("&Receive Broadcast Stream..."), "network", 0, TQT_TQOBJECT(this), TQT_SLOT(slotBroadcastReceive()), actionCollection(), "network_receive");
-	new KAction(i18n("&Save Screenshot..."), "frame_image", CTRL|Key_S, TQT_TQOBJECT(this), TQT_SLOT(slotScreenshot()), actionCollection(), "file_save_screenshot");
-	action = new KAction(i18n("Save Stream..."), "player_record", Key_R, TQT_TQOBJECT(this), TQT_SLOT(slotSaveStream()), actionCollection(), "file_save_stream");
+	m_broadcastSend = new TDEToggleAction(i18n("&Send Broadcast Stream..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(slotToggleBroadcastSend()), actionCollection(), "network_send");
+	new TDEAction(i18n("&Receive Broadcast Stream..."), "network", 0, TQT_TQOBJECT(this), TQT_SLOT(slotBroadcastReceive()), actionCollection(), "network_receive");
+	new TDEAction(i18n("&Save Screenshot..."), "frame_image", CTRL|Key_S, TQT_TQOBJECT(this), TQT_SLOT(slotScreenshot()), actionCollection(), "file_save_screenshot");
+	action = new TDEAction(i18n("Save Stream..."), "player_record", Key_R, TQT_TQOBJECT(this), TQT_SLOT(slotSaveStream()), actionCollection(), "file_save_stream");
 	action->setWhatsThis(i18n("Saves current stream to harddisc. This feature was disabled for some formats (e.g. Real Media) to prevent potential legal problems."));
 
 	/* player menu */
 
-	new KAction(i18n("Toggle Minimal Mode"), 0, 0, this, TQT_SIGNAL(signalToggleMinimalMode()), actionCollection(), "player_minimal_mode");
+	new TDEAction(i18n("Toggle Minimal Mode"), 0, 0, this, TQT_SIGNAL(signalToggleMinimalMode()), actionCollection(), "player_minimal_mode");
 
-	new KAction(i18n("Play"), "player_play", 0, TQT_TQOBJECT(this), TQT_SLOT(slotPlay()), actionCollection(), "player_play");
-	m_pauseButton = new KToggleAction(i18n("Pause"), "player_pause", Key_Space, TQT_TQOBJECT(this), TQT_SLOT(slotTogglePause()), actionCollection(), "player_pause");
-	new KAction(i18n("&Next"), "player_end", Key_PageDown, TQT_TQOBJECT(this), TQT_SLOT(slotNext()), actionCollection(), "player_next");
-	new KAction(i18n("&Previous"), "player_start", Key_PageUp, TQT_TQOBJECT(this), TQT_SLOT(slotPrevious()), actionCollection(), "player_previous");
-	new KAction(i18n("Stop"), "player_stop", Key_Backspace, TQT_TQOBJECT(this), TQT_SLOT(slotStop()), actionCollection(), "player_stop");
+	new TDEAction(i18n("Play"), "media-playback-start", 0, TQT_TQOBJECT(this), TQT_SLOT(slotPlay()), actionCollection(), "player_play");
+	m_pauseButton = new TDEToggleAction(i18n("Pause"), "media-playback-pause", Key_Space, TQT_TQOBJECT(this), TQT_SLOT(slotTogglePause()), actionCollection(), "player_pause");
+	new TDEAction(i18n("&Next"), "media-skip-forward", Key_PageDown, TQT_TQOBJECT(this), TQT_SLOT(slotNext()), actionCollection(), "player_next");
+	new TDEAction(i18n("&Previous"), "media-skip-backward", Key_PageUp, TQT_TQOBJECT(this), TQT_SLOT(slotPrevious()), actionCollection(), "player_previous");
+	new TDEAction(i18n("Stop"), "media-playback-stop", Key_Backspace, TQT_TQOBJECT(this), TQT_SLOT(slotStop()), actionCollection(), "player_stop");
 
-	new KAction(i18n("&Fast Forward"), "player_fwd", ALT|Key_Right, TQT_TQOBJECT(this), TQT_SLOT(slotFastForward()), actionCollection(), "player_ff");
-	new KAction(i18n("Slow &Motion"), 0, ALT|Key_Left, TQT_TQOBJECT(this), TQT_SLOT(slotSlowMotion()), actionCollection(), "player_slowmotion");
+	new TDEAction(i18n("&Fast Forward"), "media-seek-forward", ALT|Key_Right, TQT_TQOBJECT(this), TQT_SLOT(slotFastForward()), actionCollection(), "player_ff");
+	new TDEAction(i18n("Slow &Motion"), 0, ALT|Key_Left, TQT_TQOBJECT(this), TQT_SLOT(slotSlowMotion()), actionCollection(), "player_slowmotion");
 
-	new KAction(i18n("Skip Forward (20s)"), NULL, Key_Right, TQT_TQOBJECT(this), TQT_SLOT(slotPosPlusSmall()), actionCollection(), "player_posplus_small");
-	new KAction(i18n("Skip Backward (20s)"), NULL, Key_Left, TQT_TQOBJECT(this), TQT_SLOT(slotPosMinusSmall()), actionCollection(), "player_posminus_small");
-	new KAction(i18n("Skip Forward (1m)"), NULL, CTRL|Key_PageUp, TQT_TQOBJECT(this), TQT_SLOT(slotPosPlusMedium()), actionCollection(), "player_posplus_medium");
-	new KAction(i18n("Skip Backward (1m)"), NULL, CTRL|Key_PageDown, TQT_TQOBJECT(this), TQT_SLOT(slotPosMinusMedium()), actionCollection(), "player_posminus_medium");
-	new KAction(i18n("Skip Forward (10m)"), NULL, ALT|Key_PageUp, TQT_TQOBJECT(this), TQT_SLOT(slotPosPlusLarge()), actionCollection(), "player_posplus_large");
-	new KAction(i18n("Skip Backward (10m)"), NULL, ALT|Key_PageDown, TQT_TQOBJECT(this), TQT_SLOT(slotPosMinusLarge()), actionCollection(), "player_posminus_large");
-	new KAction(i18n("Jump to Position..."), "goto", CTRL|Key_J, TQT_TQOBJECT(this), TQT_SLOT(slotJumpToPosition()), actionCollection(), "player_jump_to");
+	new TDEAction(i18n("Skip Forward (20s)"), NULL, Key_Right, TQT_TQOBJECT(this), TQT_SLOT(slotPosPlusSmall()), actionCollection(), "player_posplus_small");
+	new TDEAction(i18n("Skip Backward (20s)"), NULL, Key_Left, TQT_TQOBJECT(this), TQT_SLOT(slotPosMinusSmall()), actionCollection(), "player_posminus_small");
+	new TDEAction(i18n("Skip Forward (1m)"), NULL, CTRL|Key_PageUp, TQT_TQOBJECT(this), TQT_SLOT(slotPosPlusMedium()), actionCollection(), "player_posplus_medium");
+	new TDEAction(i18n("Skip Backward (1m)"), NULL, CTRL|Key_PageDown, TQT_TQOBJECT(this), TQT_SLOT(slotPosMinusMedium()), actionCollection(), "player_posminus_medium");
+	new TDEAction(i18n("Skip Forward (10m)"), NULL, ALT|Key_PageUp, TQT_TQOBJECT(this), TQT_SLOT(slotPosPlusLarge()), actionCollection(), "player_posplus_large");
+	new TDEAction(i18n("Skip Backward (10m)"), NULL, ALT|Key_PageDown, TQT_TQOBJECT(this), TQT_SLOT(slotPosMinusLarge()), actionCollection(), "player_posminus_large");
+	new TDEAction(i18n("Jump to Position..."), "goto", CTRL|Key_J, TQT_TQOBJECT(this), TQT_SLOT(slotJumpToPosition()), actionCollection(), "player_jump_to");
 
-	new KAction(i18n("DVD Menu Left"), 0, CTRL|Key_Left, TQT_TQOBJECT(this), TQT_SLOT(slotDVDMenuLeft()), actionCollection(), "dvdmenuleft");
-	new KAction(i18n("DVD Menu Right"), 0, CTRL|Key_Right, TQT_TQOBJECT(this), TQT_SLOT(slotDVDMenuRight()), actionCollection(), "dvdmenuright");
-	new KAction(i18n("DVD Menu Up"), 0, CTRL|Key_Up, TQT_TQOBJECT(this), TQT_SLOT(slotDVDMenuUp()), actionCollection(), "dvdmenuup");
-	new KAction(i18n("DVD Menu Down"), 0, CTRL|Key_Down, TQT_TQOBJECT(this), TQT_SLOT(slotDVDMenuDown()), actionCollection(), "dvdmenudown");
-	new KAction(i18n("DVD Menu Select"), 0, CTRL|Key_Return, TQT_TQOBJECT(this), TQT_SLOT(slotDVDMenuSelect()), actionCollection(), "dvdmenuselect");
+	new TDEAction(i18n("DVD Menu Left"), 0, CTRL|Key_Left, TQT_TQOBJECT(this), TQT_SLOT(slotDVDMenuLeft()), actionCollection(), "dvdmenuleft");
+	new TDEAction(i18n("DVD Menu Right"), 0, CTRL|Key_Right, TQT_TQOBJECT(this), TQT_SLOT(slotDVDMenuRight()), actionCollection(), "dvdmenuright");
+	new TDEAction(i18n("DVD Menu Up"), 0, CTRL|Key_Up, TQT_TQOBJECT(this), TQT_SLOT(slotDVDMenuUp()), actionCollection(), "dvdmenuup");
+	new TDEAction(i18n("DVD Menu Down"), 0, CTRL|Key_Down, TQT_TQOBJECT(this), TQT_SLOT(slotDVDMenuDown()), actionCollection(), "dvdmenudown");
+	new TDEAction(i18n("DVD Menu Select"), 0, CTRL|Key_Return, TQT_TQOBJECT(this), TQT_SLOT(slotDVDMenuSelect()), actionCollection(), "dvdmenuselect");
 
-	m_audioChannels = new KSelectAction(i18n("Audio Channel"), 0, actionCollection(), "audio_channels");
+	m_audioChannels = new TDESelectAction(i18n("Audio Channel"), 0, actionCollection(), "audio_channels");
 	m_audioChannels->setToolTip(i18n("Select audio channel"));
 	m_audioChannels->setComboWidth( 50 );
 	connect(m_audioChannels, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(slotSetAudioChannel(int )));
-	new KAction(i18n("&Next Audio Channel"), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(slotNextAudioChannel()), actionCollection(), "next_audio_channels");
-	m_audioVisual = new KSelectAction(i18n("Audio &Visualization"), 0, actionCollection(), "audio_visualization");
+	new TDEAction(i18n("&Next Audio Channel"), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(slotNextAudioChannel()), actionCollection(), "next_audio_channels");
+	m_audioVisual = new TDESelectAction(i18n("Audio &Visualization"), 0, actionCollection(), "audio_visualization");
 	connect(m_audioVisual, TQT_SIGNAL(activated(const TQString&)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotSetVisualPlugin(const TQString&)));
-	new KAction(i18n("&Mute"), "player_mute", Key_U, TQT_TQOBJECT(this), TQT_SLOT(slotMute()), actionCollection(), "audio_mute");
-	new KAction(i18n("Volume Up"), NULL, Key_Plus, TQT_TQOBJECT(this), TQT_SLOT(slotVolumeUp()), actionCollection(), "volume_increase");
-	new KAction(i18n("Volume Down"), NULL, Key_Minus, TQT_TQOBJECT(this), TQT_SLOT(slotVolumeDown()), actionCollection(), "volume_decrease");
+	new TDEAction(i18n("&Mute"), "player_mute", Key_U, TQT_TQOBJECT(this), TQT_SLOT(slotMute()), actionCollection(), "audio_mute");
+	new TDEAction(i18n("Volume Up"), NULL, Key_Plus, TQT_TQOBJECT(this), TQT_SLOT(slotVolumeUp()), actionCollection(), "volume_increase");
+	new TDEAction(i18n("Volume Down"), NULL, Key_Minus, TQT_TQOBJECT(this), TQT_SLOT(slotVolumeDown()), actionCollection(), "volume_decrease");
 
-	m_deinterlaceEnabled = new KToggleAction(i18n("&Deinterlace"), 0, Key_I, TQT_TQOBJECT(m_xine), TQT_SLOT(slotToggleDeinterlace()), actionCollection(), "video_deinterlace");
+	m_deinterlaceEnabled = new TDEToggleAction(i18n("&Deinterlace"), 0, Key_I, TQT_TQOBJECT(m_xine), TQT_SLOT(slotToggleDeinterlace()), actionCollection(), "video_deinterlace");
 	m_deinterlaceEnabled->setWhatsThis(i18n("Activate this for interlaced streams, some DVD's for example."));
-	new KAction(i18n("&Auto"), "viewmagfit", Key_F5, TQT_TQOBJECT(m_xine), TQT_SLOT(slotAspectRatioAuto()), actionCollection(), "aspect_auto");
-	new KAction(i18n("&4:3"), "viewmagfit", Key_F6, TQT_TQOBJECT(m_xine), TQT_SLOT(slotAspectRatio4_3()), actionCollection(), "aspect_43");
-	new KAction(i18n("A&namorphic"), "viewmagfit", Key_F7, TQT_TQOBJECT(m_xine), TQT_SLOT(slotAspectRatioAnamorphic()), actionCollection(), "aspect_anamorphic");
-	new KAction(i18n("&DVB"), "viewmagfit", Key_F8, TQT_TQOBJECT(m_xine), TQT_SLOT(slotAspectRatioDVB()), actionCollection(), "aspect_dvb");
-	new KAction(i18n("&Square"), "viewmagfit", Key_F9, TQT_TQOBJECT(m_xine), TQT_SLOT(slotAspectRatioSquare()), actionCollection(), "aspect_square");
+	new TDEAction(i18n("&Auto"), "zoom-fit-best", Key_F5, TQT_TQOBJECT(m_xine), TQT_SLOT(slotAspectRatioAuto()), actionCollection(), "aspect_auto");
+	new TDEAction(i18n("&4:3"), "zoom-fit-best", Key_F6, TQT_TQOBJECT(m_xine), TQT_SLOT(slotAspectRatio4_3()), actionCollection(), "aspect_43");
+	new TDEAction(i18n("A&namorphic"), "zoom-fit-best", Key_F7, TQT_TQOBJECT(m_xine), TQT_SLOT(slotAspectRatioAnamorphic()), actionCollection(), "aspect_anamorphic");
+	new TDEAction(i18n("&DVB"), "zoom-fit-best", Key_F8, TQT_TQOBJECT(m_xine), TQT_SLOT(slotAspectRatioDVB()), actionCollection(), "aspect_dvb");
+	new TDEAction(i18n("&Square"), "zoom-fit-best", Key_F9, TQT_TQOBJECT(m_xine), TQT_SLOT(slotAspectRatioSquare()), actionCollection(), "aspect_square");
 	KStdAction::zoomIn(TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomIn()), actionCollection(), "zoom_in");
 	KStdAction::zoomOut(TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomOut()), actionCollection(), "zoom_out");
 	KStdAction::fitToPage(TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomOff()), actionCollection(), "zoom_off");
-	new KAction(i18n("Zoom In Horizontal"), NULL, CTRL|Key_H, TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomInX()), actionCollection(), "zoom_in_x");
-	new KAction(i18n("Zoom Out Horizontal"), NULL, CTRL|SHIFT|Key_H, TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomOutX()), actionCollection(), "zoom_out_x");
-	new KAction(i18n("Zoom In Vertical"), NULL, CTRL|Key_V, TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomInY()), actionCollection(), "zoom_in_y");
-	new KAction(i18n("Zoom Out Vertical"), NULL, CTRL|SHIFT|Key_V, TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomOutY()), actionCollection(), "zoom_out_y");
-	new KAction(i18n("Deinterlace &Quality"), "blend", CTRL|Key_I, TQT_TQOBJECT(this), TQT_SLOT(slotDeinterlaceQuality()), actionCollection(), "video_deinterlace_quality");
-	new KAction(i18n("&Video Settings"), "configure", Key_V, TQT_TQOBJECT(this), TQT_SLOT(slotPictureSettings()), actionCollection(), "video_picture");
-	new KAction(i18n("&Equalizer"), NULL, Key_E, TQT_TQOBJECT(this), TQT_SLOT(slotEqualizer()), actionCollection(), "equalizer");
+	new TDEAction(i18n("Zoom In Horizontal"), NULL, CTRL|Key_H, TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomInX()), actionCollection(), "zoom_in_x");
+	new TDEAction(i18n("Zoom Out Horizontal"), NULL, CTRL|SHIFT|Key_H, TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomOutX()), actionCollection(), "zoom_out_x");
+	new TDEAction(i18n("Zoom In Vertical"), NULL, CTRL|Key_V, TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomInY()), actionCollection(), "zoom_in_y");
+	new TDEAction(i18n("Zoom Out Vertical"), NULL, CTRL|SHIFT|Key_V, TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomOutY()), actionCollection(), "zoom_out_y");
+	new TDEAction(i18n("Deinterlace &Quality"), "blend", CTRL|Key_I, TQT_TQOBJECT(this), TQT_SLOT(slotDeinterlaceQuality()), actionCollection(), "video_deinterlace_quality");
+	new TDEAction(i18n("&Video Settings"), "configure", Key_V, TQT_TQOBJECT(this), TQT_SLOT(slotPictureSettings()), actionCollection(), "video_picture");
+	new TDEAction(i18n("&Equalizer"), NULL, Key_E, TQT_TQOBJECT(this), TQT_SLOT(slotEqualizer()), actionCollection(), "equalizer");
 
 
-	m_subtitles = new KSelectAction(i18n("Subtitle"), 0, actionCollection(), "player_subtitles");
+	m_subtitles = new TDESelectAction(i18n("Subtitle"), 0, actionCollection(), "player_subtitles");
 	m_subtitles->setToolTip(i18n("Select Subtitle"));
 	m_subtitles->setComboWidth( 50 );
 	connect(m_subtitles, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(slotSetSubtitle(int)));
-	new KAction(i18n("&Next Subtitle Channel"), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(slotNextSubtitleChannel()), actionCollection(), "next_player_subtitles");
-	new KAction(i18n("Delay Subtitle"), 0, CTRL|ALT|Key_Left, TQT_TQOBJECT(this), TQT_SLOT(slotDelaySubTitle()), actionCollection(), "adv_sub");
-	new KAction(i18n("Advance Subtitle"), 0, CTRL|ALT|Key_Right, TQT_TQOBJECT(this), TQT_SLOT(slotAdvanceSubTitle()), actionCollection(), "delay_sub");
-	new KAction(i18n("Add subtitle..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(slotAddSubtitle()), actionCollection(), "add_subtitle");
+	new TDEAction(i18n("&Next Subtitle Channel"), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(slotNextSubtitleChannel()), actionCollection(), "next_player_subtitles");
+	new TDEAction(i18n("Delay Subtitle"), 0, CTRL|ALT|Key_Left, TQT_TQOBJECT(this), TQT_SLOT(slotDelaySubTitle()), actionCollection(), "adv_sub");
+	new TDEAction(i18n("Advance Subtitle"), 0, CTRL|ALT|Key_Right, TQT_TQOBJECT(this), TQT_SLOT(slotAdvanceSubTitle()), actionCollection(), "delay_sub");
+	new TDEAction(i18n("Add subtitle..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(slotAddSubtitle()), actionCollection(), "add_subtitle");
 
-	new KAction(i18n("&Menu Toggle"), "view_detailed", Key_D, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuToggle()), actionCollection(), "dvd_toggle");
-	new KAction(i18n("&Title"), NULL, 0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuTitle()), actionCollection(), "dvd_title");
-	new KAction(i18n("&Root"), NULL, 0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuRoot()), actionCollection(), "dvd_root");
-	new KAction(i18n("&Subpicture"), NULL, 0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuSubpicture()), actionCollection(), "dvd_subpicture");
-	new KAction(i18n("&Audio"), NULL, 0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuAudio()), actionCollection(), "dvd_audio");
-	new KAction(i18n("An&gle"), NULL, 0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuAngle()), actionCollection(), "dvd_angle");
-	new KAction(i18n("&Part"), NULL, 0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuPart()), actionCollection(), "dvd_part");
+	new TDEAction(i18n("&Menu Toggle"), "view_detailed", Key_D, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuToggle()), actionCollection(), "dvd_toggle");
+	new TDEAction(i18n("&Title"), NULL, 0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuTitle()), actionCollection(), "dvd_title");
+	new TDEAction(i18n("&Root"), NULL, 0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuRoot()), actionCollection(), "dvd_root");
+	new TDEAction(i18n("&Subpicture"), NULL, 0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuSubpicture()), actionCollection(), "dvd_subpicture");
+	new TDEAction(i18n("&Audio"), NULL, 0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuAudio()), actionCollection(), "dvd_audio");
+	new TDEAction(i18n("An&gle"), NULL, 0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuAngle()), actionCollection(), "dvd_angle");
+	new TDEAction(i18n("&Part"), NULL, 0, TQT_TQOBJECT(m_xine), TQT_SLOT(slotMenuPart()), actionCollection(), "dvd_part");
 
-	m_dvdTitles = new KSelectAction(i18n("Titles"), 0, actionCollection(), "dvd_title_menu");
+	m_dvdTitles = new TDESelectAction(i18n("Titles"), 0, actionCollection(), "dvd_title_menu");
 	connect(m_dvdTitles, TQT_SIGNAL(activated(const TQString&)), TQT_TQOBJECT(this), TQT_SLOT(slotSetDVDTitle(const TQString&)));
-	m_dvdChapters = new KSelectAction(i18n("Chapters"), 0, actionCollection(), "dvd_chapter_menu");
+	m_dvdChapters = new TDESelectAction(i18n("Chapters"), 0, actionCollection(), "dvd_chapter_menu");
 	connect(m_dvdChapters, TQT_SIGNAL(activated(const TQString&)), TQT_TQOBJECT(this), TQT_SLOT(slotSetDVDChapter(const TQString&)));
-	m_dvdAngles = new KSelectAction(i18n("Angles"), 0, actionCollection(), "dvd_angle_menu");
+	m_dvdAngles = new TDESelectAction(i18n("Angles"), 0, actionCollection(), "dvd_angle_menu");
 	connect(m_dvdAngles, TQT_SIGNAL(activated(const TQString&)), TQT_TQOBJECT(this), TQT_SLOT(slotSetDVDAngle(const TQString&)));
 
-	new KAction(i18n("Track &Info"), "info", 0 , TQT_TQOBJECT(this), TQT_SLOT(slotInfo()), actionCollection(), "player_track_info");
-	new KAction(i18n("Effect &Plugins..."), "filter", Key_X, TQT_TQOBJECT(this), TQT_SLOT(slotFilterDialog()), actionCollection(), "player_post_filters");
+	new TDEAction(i18n("Track &Info"), "application-vnd.tde.info", 0 , TQT_TQOBJECT(this), TQT_SLOT(slotInfo()), actionCollection(), "player_track_info");
+	new TDEAction(i18n("Effect &Plugins..."), "filter", Key_X, TQT_TQOBJECT(this), TQT_SLOT(slotFilterDialog()), actionCollection(), "player_post_filters");
 
 	/* settings menu */
-	new KAction(i18n("&xine Engine Parameters"), "edit", 0, TQT_TQOBJECT(this), TQT_SLOT(slotConfigXine()), actionCollection(), "settings_xine_parameter");
+	new TDEAction(i18n("&xine Engine Parameters"), "edit", 0, TQT_TQOBJECT(this), TQT_SLOT(slotConfigXine()), actionCollection(), "settings_xine_parameter");
 
 	m_volume = new VolumeSlider();
 	TQToolTip::add
@@ -1440,7 +1440,7 @@ void XinePart::initActions()
 	m_playTime = new TQPushButton(0);
 	TQToolTip::add
 		(m_playTime, i18n("Short click: Toggle Timer Forward/Backward\nLong click: Toggle Timer OSD"));
-	TQFontMetrics met(KGlobalSettings::generalFont());
+	TQFontMetrics met(TDEGlobalSettings::generalFont());
 	m_playTime->setFixedWidth(met.width("-55:55:55") + 6);
 	m_playTime->setSizePolicy(TQSizePolicy (TQSizePolicy::Fixed, TQSizePolicy::Fixed));
 	m_playTime->setFocusPolicy(TQ_NoFocus);
@@ -1487,7 +1487,7 @@ void XinePart::loadConfig()
 {
 	kdDebug() << "XinePart: load config" << endl;
 
-	KConfig* config = instance()->config();
+	TDEConfig* config = instance()->config();
 
 	config->setGroup("General Options");
 	if (m_xine->SoftwareMixing())
@@ -1538,7 +1538,7 @@ void XinePart::saveConfig()
 
 	kdDebug() << "XinePart: save config" << endl;
 
-	KConfig* config = instance()->config();
+	TDEConfig* config = instance()->config();
 
 	config->setGroup("General Options");
 	config->writeEntry("Volume", m_volume->value());
@@ -1658,7 +1658,7 @@ void XinePart::audiocdMRLS(MRL::List& mrls, bool& ok, bool& supported, const TQS
 		if (progress->wasCancelled())
 			break;
 		progress->progressBar()->setProgress(i+1);
-		KApplication::kApplication()->processEvents();
+		TDEApplication::kApplication()->processEvents();
 	}
 
 	xine_dispose(xineStreamForMeta);
